create table tb_product
(
    id               varchar(36)  not null
        primary key,
    user_id          varchar(32)  null comment '用户id',
    buy_user_id          varchar(32)  null comment '采购用户id',
    company_name     varchar(64)  null comment '供应商名称',
    user_name        varchar(32)  null comment '客户姓名',
    phone            varchar(32)  null comment '客户电话',
    address          varchar(128) null comment '提货地址',
    address_id         varchar(32) null comment '地址id',
    pic        text         null comment '报价照片',
    price          decimal(10, 2) default 0.00              not null comment '单价',
    num       bigint(32)     default 0                 null comment '暂定数量、',
    audit_status     int          null comment '审核状态 0审核中 1 审核通过 2审核未通过',
    show_status     int          null comment '挂单状态 0挂单 1 已撤单',
    product_type          int          null comment '期货现货 0期货 1 现货',
    transaction_time      datetime     null comment '交货时间',
    create_by        varchar(50)  null comment '创建人',
    create_time      datetime     null comment '创建日期',
    update_by        varchar(50)  null comment '更新人',
    update_time      datetime     null comment '更新日期',
    sys_org_code     varchar(64)  null comment '所属部门',
    del_flag              tinyint(1)     default 0                 not null comment '删除标识0-正常,1-已删除'
);


create table tb_user_role
(
    id               varchar(36)  not null
        primary key,
    user_id          varchar(32)  null comment '用户id',
    role             int          null comment '角色信息 1供应商 2采购商',
    user_name        varchar(32)  null comment '用户名',
    company_name     varchar(64)  null comment '公司名称',
    tax_code         varchar(32)  null comment '税收编码',
    address          varchar(128) null comment '公司地址',
    bank_account     varchar(32)  null comment '公司账号',
    phone            varchar(32)  null comment '电话',
    bank_nama        varchar(32)  null comment '开户行',
    business_license text         null comment '营业执照上传',
    basic_account    text         null comment '基本户信息照片上传',
    bank_info        text         null comment '收款银行照片上传',
    audit_status     int          null comment '审核状态 0审核中 1 审核通过 2审核未通过',
    create_by        varchar(50)  null comment '创建人',
    create_time      datetime     null comment '创建日期',
    update_by        varchar(50)  null comment '更新人',
    update_time      datetime     null comment '更新日期',
    sys_org_code     varchar(64)  null comment '所属部门'
);

create index idx_phone
    on tb_user_role (phone, user_name);

create index idx_userid
    on tb_user_role (user_id);



create table tb_suggest
(
    id           varchar(36)  not null
        primary key,
    user_id      varchar(20)  null comment '用户id',
    user_name    varchar(32)  null comment '用户名',
    user_phone   varchar(64)  null comment '用户手机号',
    content      longtext     null comment '问题描述',
    proof_img    longtext     null comment '问题截图',
    submit_time  date         null comment '提交时间',
    is_reply     int          null comment '是否回复（0：未回复 1：已回复）',
    reply_msg    varchar(512) null comment '回复结果',
    reply_time   date         null comment '回复时间',
    reply_id     varchar(19)  null comment '回复人',
    create_by    varchar(50)  null comment '创建人',
    create_time  date         null comment '创建日期',
    update_by    varchar(50)  null comment '更新人',
    update_time  date         null comment '更新日期',
    sys_org_code varchar(64)  null comment '所属部门'
);

create table tb_customs
(
    id               varchar(36)  not null
        primary key,
    user_id          varchar(32)  null comment '用户id',
    role             int          null comment '角色信息 1供应商 2采购商',
    user_name        varchar(32)  null comment '用户名',
    password         varchar(64)  null comment '密码',
    company_name     varchar(64)  null comment '公司名称',
    tax_code         varchar(32)  null comment '税收编码',
    address          varchar(128) null comment '公司地址',
    bank_account     varchar(32)  null comment '公司账号',
    phone            varchar(32)  null comment '电话',
    bank_nama        varchar(32)  null comment '开户行',
    business_license longtext     null comment '营业执照上传',
    basic_account    longtext     null comment '基本户信息照片上传',
    bank_info        longtext     null comment '收款银行照片上传',
    audit_status     int          null comment '审核状态 0审核中 1 审核通过 2审核未通过',
    create_by        varchar(50)  null comment '创建人',
    create_time      date         null comment '创建日期',
    update_by        varchar(50)  null comment '更新人',
    update_time      date         null comment '更新日期',
    sys_org_code     varchar(64)  null comment '所属部门'
);
