package org.jeecg.modules.address.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.address.entity.TbAddress;
import org.jeecg.modules.address.service.ITbAddressService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 用户地址表
 * @Author: jeecg-boot
 * @Date:   2024-10-19
 * @Version: V1.0
 */
@Api(tags="用户地址表")
@RestController
@RequestMapping("/address/tbAddress")
@Slf4j
public class TbAddressController extends JeecgController<TbAddress, ITbAddressService> {
	@Autowired
	private ITbAddressService tbAddressService;
	
	/**
	 * 分页列表查询
	 *
	 * @param tbAddress
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "用户地址表-分页列表查询")
	@ApiOperation(value="用户地址表-分页列表查询", notes="用户地址表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TbAddress>> queryPageList(TbAddress tbAddress,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TbAddress> queryWrapper = QueryGenerator.initQueryWrapper(tbAddress, req.getParameterMap());
		Page<TbAddress> page = new Page<TbAddress>(pageNo, pageSize);
		IPage<TbAddress> pageList = tbAddressService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param tbAddress
	 * @return
	 */
	@AutoLog(value = "用户地址表-添加")
	@ApiOperation(value="用户地址表-添加", notes="用户地址表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TbAddress tbAddress) {
		tbAddressService.save(tbAddress);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param tbAddress
	 * @return
	 */
	@AutoLog(value = "用户地址表-编辑")
	@ApiOperation(value="用户地址表-编辑", notes="用户地址表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TbAddress tbAddress) {
		tbAddressService.updateById(tbAddress);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "用户地址表-通过id删除")
	@ApiOperation(value="用户地址表-通过id删除", notes="用户地址表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		tbAddressService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "用户地址表-批量删除")
	@ApiOperation(value="用户地址表-批量删除", notes="用户地址表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.tbAddressService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "用户地址表-通过id查询")
	@ApiOperation(value="用户地址表-通过id查询", notes="用户地址表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TbAddress> queryById(@RequestParam(name="id",required=true) String id) {
		TbAddress tbAddress = tbAddressService.getById(id);
		if(tbAddress==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(tbAddress);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param tbAddress
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TbAddress tbAddress) {
        return super.exportXls(request, tbAddress, TbAddress.class, "用户地址表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TbAddress.class);
    }

}
