package org.jeecg.modules.product.controller;

import java.util.Arrays;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.product.entity.TbProduct;
import org.jeecg.modules.product.service.ITbProductService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 产品报价表
 * @Author: jeecg-boot
 * @Date:   2024-10-19
 * @Version: V1.0
 */
@Api(tags="产品报价表")
@RestController
@RequestMapping("/product/tbProduct")
@Slf4j
public class TbProductController extends JeecgController<TbProduct, ITbProductService> {
	@Autowired
	private ITbProductService tbProductService;
	
	/**
	 * 分页列表查询
	 *
	 * @param tbProduct
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "产品报价表-分页列表查询")
	@ApiOperation(value="产品报价表-分页列表查询", notes="产品报价表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TbProduct>> queryPageList(TbProduct tbProduct,
												  @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
												  @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
												  HttpServletRequest req) {
		QueryWrapper<TbProduct> queryWrapper = QueryGenerator.initQueryWrapper(tbProduct, req.getParameterMap());
		Page<TbProduct> page = new Page<TbProduct>(pageNo, pageSize);
		IPage<TbProduct> pageList = tbProductService.page(page, queryWrapper);
		return Result.OK(pageList);
	}

	/**
	 *   添加
	 *
	 * @param tbProduct
	 * @return
	 */
	@AutoLog(value = "产品报价表-添加")
	@ApiOperation(value="产品报价表-添加", notes="产品报价表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TbProduct tbProduct) {
		tbProduct.setDelFlag(0);
		tbProductService.save(tbProduct);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param tbProduct
	 * @return
	 */
	@AutoLog(value = "产品报价表-编辑")
	@ApiOperation(value="产品报价表-编辑", notes="产品报价表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TbProduct tbProduct) {
		tbProductService.updateById(tbProduct);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "产品报价表-通过id删除")
	@ApiOperation(value="产品报价表-通过id删除", notes="产品报价表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		tbProductService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "产品报价表-批量删除")
	@ApiOperation(value="产品报价表-批量删除", notes="产品报价表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.tbProductService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "产品报价表-通过id查询")
	@ApiOperation(value="产品报价表-通过id查询", notes="产品报价表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TbProduct> queryById(@RequestParam(name="id",required=true) String id) {
		TbProduct tbProduct = tbProductService.getById(id);
		if(tbProduct==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(tbProduct);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param tbProduct
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TbProduct tbProduct) {
        return super.exportXls(request, tbProduct, TbProduct.class, "产品报价表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TbProduct.class);
    }

}
